@@ -12,13 +12,14 @@ try:
 except ImportError:
     pass
 from matplotlib import get_backend
-from matplotlib.pyplot import axes, figure, gca, gcf
+from matplotlib.pyplot import axes, figure, gca, gcf, ioff
+from matplotlib.pyplot import sca as mpl_sca
 from numpy.distutils.misc_util import is_sequence
 
-from .utils import ioff
 from .widgets import RangeSlider
 
 __all__ = [
+    "sca",
     "decompose_bbox",
     "update_datalim_from_xy",
     "update_datalim_from_bbox",
@@ -43,6 +44,17 @@ __all__ = [
 ]
 
 
+def sca(ax):
+    """
+    sca that won't fail if figure not managed by pyplot
+    """
+    try:
+        mpl_sca(ax)
+    except ValueError as e:
+        if "not managed by pyplot" not in str(e):
+            raise e
+
+
 def decompose_bbox(bbox):
     return bbox.x0, bbox.y0, bbox.x1, bbox.y1
 
@@ -474,7 +486,7 @@ def create_mpl_controls_fig(kwargs):
     gap_height = 0
     if not all(map(lambda x: isinstance(x, mwidgets.AxesWidget), kwargs.values())):
         # if the only kwargs are existing matplotlib widgets don't make a new figure
-        with ioff:
+        with ioff():
             fig = figure()
         size = fig.get_size_inches()
         fig_h = widget_inches
@@ -677,7 +689,7 @@ def gogogo_figure(ipympl, ax=None):
     """
     if ax is None:
         if ipympl:
-            with ioff:
+            with ioff():
                 ax = gca()
                 fig = ax.get_figure()
         else:
